@@ -2,8 +2,9 @@
 /*
   Class struct of libisoburn.
 
-  Copyright 2007 - 2012 Vreixo Formoso Lopes <metalpain2002@yahoo.es>
-                    and Thomas Schmitt <scdbackup@gmx.net>
+  Copyright 2007 - 2009 Vreixo Formoso Lopes <metalpain2002@yahoo.es>
+  Copyright 2007 - 2023 Thomas Schmitt <scdbackup@gmx.net>
+
   Provided under GPL version 2 or later.
 */
 
@@ -20,7 +21,7 @@
 #endif
 #endif
 
-/* For emulated TOC of overwriteable media.
+/* For emulated TOC of overwritable media.
    Provides minimal info for faking a struct burn_toc_entry.
 */
 struct isoburn_toc_entry {
@@ -28,7 +29,7 @@ struct isoburn_toc_entry {
  int track_no; /* point */
  int start_lba;
  int track_blocks;
- char *volid; /* For caching a volume id from emulated toc on overwriteables */
+ char *volid; /* For caching a volume id from emulated toc on overwritables */
 
  struct isoburn_toc_entry *next;
 };
@@ -91,7 +92,7 @@ struct isoburn {
  int fabricated_msc2;
  
 
- /* The nwa to be used for a first session on the present kind of overwriteable
+ /* The nwa to be used for a first session on the present kind of overwritable
     media (usually Libisoburn_overwriteable_starT, but might be forced to 0)
  */
  int zero_nwa;
@@ -112,16 +113,16 @@ struct isoburn {
  */
  enum burn_disc_status fabricated_disc_status;
 
- /* To be set if read errors occured during media evaluation.
+ /* To be set if read errors occurred during media evaluation.
  */
  int media_read_error;
 
  /* Eventual emulated table of content read from the chain of ISO headers
-    on overwriteable media.
+    on overwritable media.
  */ 
  struct isoburn_toc_entry *toc;
 
- /* Indicator wether the most recent burn run worked :
+ /* Indicator whether the most recent burn run worked :
     -1 = undetermined, ask libburn , 0 = failure , 1 = success
     To be inquired by isoburn_drive_wrote_well()
  */
@@ -166,6 +167,9 @@ struct isoburn {
 
  /* Forwarding an image generation option to the burn wrapper */
  int do_tao;
+
+ /* Forwarding an image generation option to the burn wrapper */
+ int do_fsync;
  
 };
 
@@ -319,6 +323,12 @@ struct isoburn_read_opts {
     unsigned int nojoliet:1; /*< Do not read Joliet extensions */
     unsigned int noiso1999:1; /*< Do not read ISO 9660:1999 enhanced tree */
 
+    unsigned int do_ecma119_map:1; /* call iso_read_opts_set_ecma119_map() */
+    unsigned int map_mode:2;       /* argument for do_ecma119_map */
+
+    unsigned int do_joliet_map:1;   /* call iso_read_opts_set_joliet_map() */
+    unsigned int joliet_map_mode:1; /* for iso_read_opts_set_joliet_map */ 
+
     /* ts A90121 */
     unsigned int noaaip:1;   /* Do not read AAIP for ACL and EA */
     unsigned int noacl:1;    /* Do not read ACL from external file objects */
@@ -348,11 +358,19 @@ struct isoburn_read_opts {
      * Enable or disable methods to automatically choose an input charset.
      * This eventually overrides input_charset.
      *
-     * bit0= allow to set the input character set automatically from
+     * bit0= set the input character set automatically from
      *       attribute "isofs.cs" of root directory
      */
     int auto_input_charset;
 
+    /**
+     * What to do in case of name longer than truncate_length:
+     *  0= throw FAILURE
+     *  1= truncate to truncate_length with MD5 of whole name at end
+     */
+    int truncate_mode;
+    int truncate_length;
+
     /* modified by the function isoburn_read_image */
     unsigned int hasRR:1; /*< It will be set to 1 if RR extensions are present,
                              to 0 if not. */
@@ -370,6 +388,11 @@ struct isoburn_read_opts {
 
     uint32_t size; /**< Will be filled with the size (in 2048 byte block) of 
                     *   the image, as reported in the PVM. */
+
+    int tree_loaded; /* from iso_read_image_features_tree_loaded() */
+    int rr_loaded;   /* from iso_read_image_features_rr_loaded */
+
+
     unsigned int pretend_blank:1; /* always create empty image */
 
     uint32_t displacement;
@@ -412,7 +435,7 @@ struct isoburn_imgen_opts {
      */
     unsigned int file_md5 :2;
 
-    /* On overwriteable media or random access files do not write the first
+    /* On overwritable media or random access files do not write the first
        session to LBA 32, but rather to LBA 0 directly.
      */
     unsigned int no_emul_toc :1;
@@ -558,7 +581,7 @@ struct isoburn_imgen_opts {
     /**
      * Write AAIP as extension according to SUSP 1.10 rather than SUSP 1.12.
      * I.e. without announcing it by an ER field and thus without the need
-     * to preceed the RRIP fields by an ES and to preceed the AA field by ES.
+     * to precede the RRIP fields by an ES and to precede the AA field by ES.
      */
     unsigned int aaip_susp_1_10 :1;
 
@@ -673,13 +696,51 @@ struct isoburn_imgen_opts {
 
     /* Disk file paths of content of PreP partition and EFI system partition */
     char *prep_partition;
+    int prep_part_flag;
     char *efi_boot_partition;
+    int efi_boot_part_flag;
 
-    /* Eventual disk file paths of prepared images which shall be appended
-       after the ISO image and described by partiton table entries in a MBR.
+    /* Disk file paths of prepared images which shall be appended
+       after the ISO image and described by partition table entries in a MBR.
+       NULL means unused.
     */
     char *appended_partitions[Libisoburn_max_appended_partitionS];
     uint8_t appended_part_types[Libisoburn_max_appended_partitionS];
+    int appended_part_flags[Libisoburn_max_appended_partitionS];
+    uint8_t appended_part_type_guids[Libisoburn_max_appended_partitionS][16];
+
+    /* Flags in case that appended partitions show up in GPT:
+       bit0= appended_part_type_guids[same_index] is valid
+    */
+    uint8_t appended_part_gpt_flags[Libisoburn_max_appended_partitionS];
+
+    /* If 1: With appended partitions: create protective MBR and mark by GPT
+    */
+    int appended_as_gpt;
+
+    /* If 1: With appended partitions: mark by APM
+    */
+    int appended_as_apm;
+
+    /* If 1: Apply isohybrid gestures to non-isohybrid situations
+    */
+    int part_like_isohybrid;
+
+    /* isoburn_igopt_set_iso_mbr_part_type()
+    */
+    int iso_mbr_part_type;
+
+    /* isoburn_igopt_set_iso_type_guid()
+    */
+    uint8_t iso_gpt_type_guid[16];
+    /* bit0= iso_gpt_type_guid is valid
+    */
+    int iso_gpt_flag;
+
+    /* See libisoburn.h isoburn_igopt_set_gpt_guid()
+    */
+    uint8_t gpt_guid[16];
+    int gpt_guid_mode;
 
     /* Eventual name of the non-ISO aspect of the image. E.g. SUN ASCII label.
      */
@@ -705,10 +766,16 @@ struct isoburn_imgen_opts {
      */
     int do_tao;
 
+    /* Whether to fsync() stdio_drives after isoburn_activate_session() */
+    int do_fsync;
+
+    /* See libisoburn.h isoburn_igopt_set_max_ce_entries() */
+    uint32_t max_ce_entries;
+    int max_ce_entries_flag;
 };
 
 
-/* Alignment for session starts on overwriteable media.
+/* Alignment for session starts on overwritable media.
    (Increased from 16 to 32 blocks for aligning to BD-RE clusters.)
 */
 #define Libisoburn_nwa_alignemenT 32
@@ -748,7 +815,7 @@ struct isoburn_imgen_opts {
                                    ((off_t) (Libisoburn_target_head_sizE/2048))
 
 
-/* Wrappers for emulation of TOC on overwriteable media */
+/* Wrappers for emulation of TOC on overwritable media */
 
 struct isoburn_toc_track {
  /* Either track or toc_entry are supposed to be NULL */
