@@ -91,7 +91,7 @@ int filesrc_block_and_size(Ecma119Image *t, IsoFileSrc *src,
         *total_size += src->sections[i].size;
         if (pos != src->sections[i].block) {
             iso_msg_submit(t->image->id, ISO_SECT_SCATTERED, 0,
-                      "File sections do not form consequtive array of blocks");
+                      "File sections do not form consecutive array of blocks");
             return ISO_SECT_SCATTERED;
         }
         /* If .size is not aligned to blocks then there is a byte gap.
@@ -137,8 +137,10 @@ int iso_get_hfsplus_name(char *input_charset, int imgid, char *name,
     curlen = ucslen (ucs_name);
     *result = calloc ((curlen * HFSPLUS_MAX_DECOMPOSE_LEN + 1),
                      sizeof (uint16_t));
-    if (*result == NULL)
+    if (*result == NULL) {
+        free(ucs_name);
         return ISO_OUT_OF_MEM;
+    }
 
     for (iptr = ucs_name, optr = *result; *iptr; iptr++)
       {
@@ -208,8 +210,12 @@ int iso_get_hfsplus_name(char *input_charset, int imgid, char *name,
     while (done);
 
     *cmp_name = calloc ((ucslen (*result) + 1), sizeof (uint16_t));
-    if (*cmp_name == NULL)
-      return ISO_OUT_OF_MEM;
+    if (*cmp_name == NULL) {
+        free(ucs_name);
+        free(*result);
+        *result = NULL;
+        return ISO_OUT_OF_MEM;
+    }
 
     for (iptr = *result, optr = *cmp_name; *iptr; iptr++)
       {
@@ -399,7 +405,8 @@ int create_tree(Ecma119Image *t, IsoNode *iso, uint32_t parent_id)
 	    if (cret < 0)
 	      return cret;
 	    pos = pos->next;
-	    t->hfsp_leafs[cleaf].nchildren++;
+	    if (cret > 0)
+	      t->hfsp_leafs[cleaf].nchildren++;
 	  }
       }
     return ISO_SUCCESS;
@@ -475,7 +482,8 @@ int hfsplus_tail_writer_compute_data_blocks(IsoImageWriter *writer)
 
   t->hfsp_total_blocks = hfsp_curblock - t->hfsp_part_start;
 
-  return iso_quick_apm_entry(t, t->hfsp_part_start / block_fac,
+  return iso_quick_apm_entry(t->apm_req, &(t->apm_req_count),
+                             t->hfsp_part_start / block_fac,
 			     t->hfsp_total_blocks / block_fac +
 			     !!(t->hfsp_total_blocks % block_fac),
                             "HFSPLUS_Hybrid", "Apple_HFS");
@@ -535,11 +543,14 @@ int hfsplus_writer_compute_data_blocks(IsoImageWriter *writer)
 }
 
 
-static void set_time (uint32_t *tm, uint32_t t)
+static inline uint32_t mac_time_offset(uint32_t t)
 {
-  iso_msb ((uint8_t *) tm, t + 2082844800, 4);
+    uint32_t val;
+    iso_msb ((uint8_t *) &val, t + 2082844800, sizeof(val));
+    return val;
 }
 
+
 int nop_writer_write_vol_desc(IsoImageWriter *writer)
 {
   return ISO_SUCCESS;
@@ -607,9 +618,9 @@ write_sb (Ecma119Image *t)
     /* Cleanly unmounted, software locked.  */
     iso_msb ((uint8_t *) &sb.attributes, (1 << 8) | (1 << 15), 4);
     iso_msb ((uint8_t *) &sb.last_mounted_version, 0x6c69736f, 4);
-    set_time (&sb.ctime, t->now);
-    set_time (&sb.utime, t->now);
-    set_time (&sb.fsck_time, t->now);
+    sb.ctime = mac_time_offset(t->now);
+    sb.utime = mac_time_offset(t->now);
+    sb.fsck_time = mac_time_offset(t->now);
     iso_msb ((uint8_t *) &sb.file_count, t->hfsp_nfiles, 4);
     iso_msb ((uint8_t *) &sb.folder_count, t->hfsp_ndirs - 1, 4);
     iso_msb ((uint8_t *) &sb.blksize, block_size, 4);
@@ -842,12 +853,11 @@ int hfsplus_writer_write_data(IsoImageWriter *writer)
 		    ((uint8_t *) &common->type)[1] = t->hfsp_leafs[curnode].type;
 		    iso_msb ((uint8_t *) &common->valence, t->hfsp_leafs[curnode].nchildren, 4);
 		    iso_msb ((uint8_t *) &common->fileid, t->hfsp_leafs[curnode].cat_id, 4);
-		    set_time (&common->ctime, t->hfsp_leafs[curnode].node->ctime);
-		    set_time (&common->mtime, t->hfsp_leafs[curnode].node->mtime);
+		    common->ctime = mac_time_offset(t->hfsp_leafs[curnode].node->ctime);
+		    common->mtime = mac_time_offset(t->hfsp_leafs[curnode].node->mtime);
 		    /* FIXME: distinguish attr_mtime and mtime.  */
-		    set_time (&common->attr_mtime, t->hfsp_leafs[curnode].node->mtime);
-		    set_time (&common->atime, t->hfsp_leafs[curnode].node->atime);
-
+		    common->attr_mtime = mac_time_offset(t->hfsp_leafs[curnode].node->mtime);
+		    common->atime = mac_time_offset(t->hfsp_leafs[curnode].node->atime);
 		    iso_msb ((uint8_t *) &common->uid, px_get_uid (t, t->hfsp_leafs[curnode].node), 4);
 		    iso_msb ((uint8_t *) &common->gid, px_get_gid (t, t->hfsp_leafs[curnode].node), 4);
 		    iso_msb ((uint8_t *) &common->mode, px_get_mode (t, t->hfsp_leafs[curnode].node, (t->hfsp_leafs[curnode].type == HFSPLUS_DIR)), 2);
@@ -1569,10 +1579,18 @@ int mangle_leafs(Ecma119Image *target, int flag)
     return ISO_SUCCESS;
 }
 
+void iso_setup_hfsplus_block_size(Ecma119Image *target)
+{
+    if (target->opts->hfsp_block_size == 0)
+        target->opts->hfsp_block_size = HFSPLUS_DEFAULT_BLOCK_SIZE;
+    target->hfsp_cat_node_size = 2 * target->opts->hfsp_block_size;
+    target->hfsp_iso_block_fac = 2048 / target->opts->hfsp_block_size;
+}
+
 int hfsplus_writer_create(Ecma119Image *target)
 {
     int ret;
-    IsoImageWriter *writer;
+    IsoImageWriter *writer = NULL;
     int max_levels;
     int level = 0;
     IsoNode *pos;
@@ -1582,16 +1600,14 @@ int hfsplus_writer_create(Ecma119Image *target)
 
     writer = calloc(1, sizeof(IsoImageWriter));
     if (writer == NULL) {
-        return ISO_OUT_OF_MEM;
+        ret = ISO_OUT_OF_MEM;
+        goto ex;
     }
 
     make_hfsplus_decompose_pages();
     make_hfsplus_class_pages();
 
-    if (target->opts->hfsp_block_size == 0)
-        target->opts->hfsp_block_size = HFSPLUS_DEFAULT_BLOCK_SIZE;
-    target->hfsp_cat_node_size = 2 * target->opts->hfsp_block_size;
-    target->hfsp_iso_block_fac = 2048 / target->opts->hfsp_block_size;
+    iso_setup_hfsplus_block_size(target);
     cat_node_size = target->hfsp_cat_node_size;
 
     writer->compute_data_blocks = hfsplus_writer_compute_data_blocks;
@@ -1606,10 +1622,8 @@ int hfsplus_writer_create(Ecma119Image *target)
     target->hfsp_ndirs = 0;
     target->hfsp_cat_id = 16;
     ret = hfsplus_count_tree(target, (IsoNode*)target->image->root);
-    if (ret < 0) {
-        free((char *) writer);
-        return ret;
-    }
+    if (ret < 0)
+        goto ex;
 
     for (i = 0; i < ISO_HFSPLUS_BLESS_MAX; i++)
       target->hfsp_bless_id[i] = 0;
@@ -1619,12 +1633,13 @@ int hfsplus_writer_create(Ecma119Image *target)
 
     target->hfsp_leafs = calloc (target->hfsp_nleafs, sizeof (target->hfsp_leafs[0]));
     if (target->hfsp_leafs == NULL) {
-        return ISO_OUT_OF_MEM;
+        ret = ISO_OUT_OF_MEM;
+        goto ex;
     }
     ret = set_hfsplus_name (target, target->image->volume_id,
                             &target->hfsp_leafs[target->hfsp_curleaf]);
     if (ret < 0)
-        return ret;
+        goto ex;
     target->hfsp_leafs[target->hfsp_curleaf].node = (IsoNode *) target->image->root;
     target->hfsp_leafs[target->hfsp_curleaf].used_size = target->hfsp_leafs[target->hfsp_curleaf].strlen * 2 + 8 + 2 + sizeof (struct hfsplus_catfile_common);
 
@@ -1655,10 +1670,13 @@ int hfsplus_writer_create(Ecma119Image *target)
       {
 	int cret;
 	cret = create_tree(target, pos, 2);
-	if (cret < 0)
-	  return cret;
+	if (cret < 0) {
+	    ret = cret;
+	    goto ex;
+	}
 	pos = pos->next;
-	target->hfsp_leafs[0].nchildren++;
+	if (cret > 0)
+	    target->hfsp_leafs[0].nchildren++;
       }
 
     qsort(target->hfsp_leafs, target->hfsp_nleafs,
@@ -1666,13 +1684,14 @@ int hfsplus_writer_create(Ecma119Image *target)
 
     ret = mangle_leafs(target, 0);
     if (ret < 0)
-        return ret;
+        goto ex;
 
     for (max_levels = 0; target->hfsp_nleafs >> max_levels; max_levels++);
     max_levels += 2;
     target->hfsp_levels = calloc (max_levels, sizeof (target->hfsp_levels[0]));
     if (target->hfsp_levels == NULL) {
-        return ISO_OUT_OF_MEM;
+	ret = ISO_OUT_OF_MEM;
+	goto ex;
     }
 
     target->hfsp_nnodes = 1;
@@ -1682,9 +1701,10 @@ int hfsplus_writer_create(Ecma119Image *target)
       unsigned bytes_rem = cat_node_size - sizeof (struct hfsplus_btnode) - 2;
 
       target->hfsp_levels[level].nodes = calloc ((target->hfsp_nleafs + 1),  sizeof (target->hfsp_levels[level].nodes[0]));
-      if (!target->hfsp_levels[level].nodes)
-	return ISO_OUT_OF_MEM;
-    
+      if (!target->hfsp_levels[level].nodes) {
+	  ret = ISO_OUT_OF_MEM;
+	  goto ex;
+      }
       target->hfsp_levels[level].level_size = 0;  
       for (i = 0; i < target->hfsp_nleafs; i++)
 	{
@@ -1739,8 +1759,10 @@ int hfsplus_writer_create(Ecma119Image *target)
 	level++;
 
 	target->hfsp_levels[level].nodes = calloc (((last_size + 1) / 2),  sizeof (target->hfsp_levels[level].nodes[0]));
-	if (!target->hfsp_levels[level].nodes)
-	  return ISO_OUT_OF_MEM;
+	if (!target->hfsp_levels[level].nodes) {
+	    ret = ISO_OUT_OF_MEM;
+	    goto ex;
+        }
     
 	target->hfsp_levels[level].level_size = 0;  
 
@@ -1775,16 +1797,21 @@ int hfsplus_writer_create(Ecma119Image *target)
 
     if (target->hfsp_nnodes > (cat_node_size - 0x100) * 8)
       {
-	return iso_msg_submit(target->image->id, ISO_MANGLE_TOO_MUCH_FILES, 0,
-			      "HFS+ map nodes aren't implemented");
-
-	return ISO_MANGLE_TOO_MUCH_FILES;
+	iso_msg_submit(target->image->id, ISO_HFSPLUS_TOO_MANY_FILES, 0,
+			"HFS+ map nodes aren't implemented");
+	ret = ISO_HFSPLUS_TOO_MANY_FILES;
+	goto ex;
       }
 
     /* add this writer to image */
     target->writers[target->nwriters++] = writer;
+    writer = NULL;
 
-    return ISO_SUCCESS;
+    ret = ISO_SUCCESS;
+ex:;
+    if (writer != NULL)
+        free(writer);
+    return ret;
 }
 
 int hfsplus_tail_writer_create(Ecma119Image *target)
@@ -1831,7 +1858,7 @@ struct iso_hfsplus_xinfo_data *iso_hfsplus_xinfo_new(int flag)
 }
 
 /* The iso_node_xinfo_cloner function which gets associated to
- * iso_hfsplus_xinfo_func by iso_init() resp. iso_init_with_flag() via
+ * iso_hfsplus_xinfo_func by iso_init() or iso_init_with_flag() via
  * iso_node_xinfo_make_clonable()
  */
 int iso_hfsplus_xinfo_cloner(void *old_data, void **new_data, int flag)
