@@ -2,7 +2,7 @@
 /* xorriso - Command line oriented batch and dialog tool which creates, loads,
    manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2014 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2023 Thomas Schmitt, <scdbackup@gmx.net>
 
    Initial code of this program was derived from program src/askme.c out
    of scdbackup-0.8.8, Copyright 2007 Thomas Schmitt, BSD-License.
@@ -43,7 +43,7 @@
    --------------------------------------------------------------------------
    The following overview is relevant for development but not for usage of
    xorriso. An application programmer should read xorriso.h and man xorriso
-   resp. info xorriso, rather than diving into its source code.
+   (or info xorriso), rather than diving into its source code.
    For examples see the functions main() and check_compatibility() below.
    --------------------------------------------------------------------------
 
@@ -70,17 +70,17 @@
    aux_objects.c    various helper classes
    misc_funct.c     miscellaneous helper functions
    findjob.c        performs tree searches in libisofs or in POSIX filesystem
-   check_media.c    perform verifying runs on media resp. images
+   check_media.c    perform verifying runs on media or images
    text_io.c        text i/o functions
    match.c          functions for pattern matching
    emulators.c      emulators for mkisofs and cdrecord
    disk_ops.c       actions on onjects of disk filesystems
    cmp_update.c     compare or update files between disk filesystem and
                     ISO filesystem
-   opts_a_c.c       options -a* to -c*
-   opts_d_h.c       options -d* to -h*
-   opts_i_o.c       options -i* to -o*
-   opts_p_z.c       options -p* to -z*
+   opts_a_c.c       commands -a* to -c*
+   opts_d_h.c       commands -d* to -h*
+   opts_i_o.c       commands -i* to -o*
+   opts_p_z.c       commands -p* to -z*
 
    xorriso_private.h contains the definition of struct Xorriso and for
    convenience includes the .h files of the non-library group.
@@ -110,7 +110,7 @@
    version of xorriso.
 */
 #define Xorriso_req_majoR  1
-#define Xorriso_req_minoR  3
+#define Xorriso_req_minoR  5
 #define Xorriso_req_micrO  6
 
 
@@ -135,7 +135,7 @@ static void check_compatibility()
  int lib_major, lib_minor, lib_micro;
 
 /* First an ugly compile time check for header version compatibility.
-   If everthing matches, then no C code is produced. In case of mismatch,
+   If everything matches, then no C code is produced. In case of mismatch,
    intentionally faulty C code will be inserted.
 */
 /* The minimum requirement of xorriso towards the libisoburn header
@@ -155,7 +155,7 @@ static void check_compatibility()
       error: 'INTENTIONAL_ABORT_OF_COMPILATION__HEADERFILE_xorriso_dot_h_TOO_OLD__SEE_xorriso_main_dot_c' undeclared (first use in this function)
       error: 'XORRISO_MISCONFIGURATION_' undeclared (first use in this function)
 */
-/* The indendation is an advise of man gcc to help old compilers ignoring */
+/* The indentation is an advise of man gcc to help old compilers ignoring */
  #if Xorriso_req_majoR > Xorriso_header_version_majoR
  #define Xorriso_dot_h_too_olD 1
  #endif
@@ -213,8 +213,8 @@ int main(int argc, char **argv)
 
  if(argc < 2) {
    yell_xorriso();
-   fprintf(stderr,"usage : %s [options]\n", argv[0]);
-   fprintf(stderr, "        More is told by option -help\n");
+   fprintf(stderr,"usage : %s [commands]\n", argv[0]);
+   fprintf(stderr, "        More is told by command -help\n");
    exit(2);
  }
  setlocale(LC_CTYPE, "");
